# こてまりライブラリ
## 1. 目的・背景
### 目的

ユーザーが編集中のファイルに対して、プロジェクト全体のコンテキストを迅速かつ正確に取得し、システムプロンプトやエディタ連携などで活用できる仕組みを提供する。

### 背景

プロジェクト規模が大きくなるにつれ、関連ファイルの把握や不要ファイルの除外、キャッシュ管理が複雑化するため、これらを自動化・最適化するライブラリが必要とされる。

## 2. システム概要
__概要__

こてまりは、指定されたソフトウェアプロジェクト内のファイル群を解析し、ユーザーが編集中のファイルに関連するコンテキストを取得するためのPythonライブラリです。

プロジェクトのディレクトリ構成、言語特性、.gitignoreなどの除外ルールを考慮し、必要な情報のみを抽出します。

## 3. 機能要件
### 3.1 プロジェクト解析モジュール
プロジェクトルートからディレクトリツリーを走査し、言語ごとの特性に基づいたファイル群を特定する。

__除外ルール__

.gitignore やプロジェクト固有のファイル（例: ビルド成果物、一時ファイル）を参照し、不要なファイル・ディレクトリを除外する。

### 3.2 システムプロンプト生成機能
関連ファイルの内容を結合し、システムプロンプトとして出力可能なフォーマットに整形する。

ファイル間の依存関係や優先順位に基づき、必要なコンテキスト情報を最適化して提供する。

### 3.3 キャッシュ管理・変更検出機能
各ファイルの最終更新時刻やハッシュ値を記録し、キャッシュとして保存する。

ファイル変更の検知により、キャッシュの有効性を判断し、必要に応じて再解析を実施する。

### 3.4 構文解析・依存関係抽出機能
Pythonでは AST などを利用して、コード内の依存関係や関連する定義・呼び出しを解析する。

他言語の場合は、プラグインやモジュール方式で解析ロジックを拡張可能にする。

### 3.5 外部ライブラリドキュメント取り込み機能
利用ライブラリごとにドキュメントURLを指定し、必要に応じて自動ダウンロードとローカルキャッシュを実施する。

ドキュメントの更新チェックやキャッシュ更新の仕組みを組み込む。

### 3.6 インストール・セットアップ機能
pip での簡単インストールを前提とし、依存パッケージやセットアップスクリプトを提供する。

CLI ツールとしての利用、またはエディタ連携用プラグインとしても利用可能にする。

### 3.7 ユーザー設定・拡張機能
ユーザーが設定ファイル（例: .kotemari.yml）で除外ルール、キャッシュ動作、解析パラメータなどをカスタマイズできるようにする。

API の拡張性を確保し、他ツールや自動化スクリプトとの連携を促進する。

### 3.8 エラーハンドリング・ログ管理機能
解析中や外部リソース取得時のエラーに対する例外処理を適切に実装する。

ログ出力機能を整備し、問題発生時に詳細なデバッグ情報を提供する。

### 3.9 ファイル一覧、ツリー化機能
ファイルの一覧リストやツリーの文字列として、プロジェクトのファイルを取得できる。

## 4. 非機能要件
### 4.1 パフォーマンス
大規模プロジェクトでも迅速な解析とコンテキスト取得が可能な設計とする。
キャッシュ管理により、再解析のオーバーヘッドを最小限に抑える。

### 4.2 拡張性・保守性
プラグイン方式による解析ロジックの拡張が容易であること。
設定ファイルやAPIを通じて、ユーザーや開発者がカスタマイズしやすい構造とする。

## 5. システム構成
__コアライブラリ__

プロジェクト解析、キャッシュ管理、構文解析、システムプロンプト生成の各機能をモジュール化。

__ユーザーインターフェース__

CLI ツールとしての利用や、エディタ連携用のAPIを提供する。

__プラグイン・拡張モジュール__

複数言語対応、外部ライブラリドキュメント取り込みなどの拡張機能をプラグイン形式で実装。

## 6. その他の要件
### 6.1 APIとしての提供
シンプルなAPIを提供し、ユーザーがプロジェクト全体のコンテキストを取得・表示できるようにする。

## 6.2 ドキュメントとサポート
利用方法、設定方法、拡張方法を記載したユーザーガイドを整備する。

インストール方法、トラブルシューティング、FAQ などのオンラインドキュメントを提供する。
