# 要件定義書

## プロジェクトの目的・背景

### プロジェクトの目的

ユーザーが編集中のファイルに対して、プロジェクト全体のコンテキスト（関連ファイルや依存関係など）を迅速かつ正確に取得し、システムプロンプト生成やエディタ連携などで活用できる仕組みを提供することを目的とします。

### プロジェクトの背景

ソフトウェア開発において、特に大規模なプロジェクトでは、編集中のファイルに関連する他のファイルを把握したり、ビルド成果物などの不要なファイルを除外したり、変更を検知してキャッシュを管理したりすることが複雑になりがちです。これらの作業を自動化・最適化し、開発効率を向上させるためのライブラリが求められています。このライブラリ「こてまり」は、これらの課題解決を目指します。

## 利用者と困りごと

| 利用者の種類         | 利用者のゴール                                                                 | 利用者の制約                                 | 利用者の困りごと                                                                                                |
| :------------------- | :----------------------------------------------------------------------------- | :------------------------------------------- | :-------------------------------------------------------------------------------------------------------------- |
| ソフトウェア開発者   | 開発中のプロジェクト全体の構造や依存関係を素早く理解し、効率的にコーディングしたい | プロジェクトの規模や複雑さに応じて情報が増大する | ・関連ファイルを探すのに時間がかかる<br>・不要なファイル（ビルド成果物など）がノイズになる<br>・依存関係の把握が難しい<br>・毎回コンテキストを手動で準備するのが面倒 |
| AI（LLM）            | 開発者から与えられたタスク（コード生成、リファクタリング等）を正確に実行したい       | 入力コンテキストの質と量に性能が依存する     | ・タスク実行に必要なプロジェクトコンテキストが不足している<br>・冗長または無関係な情報が多く含まれている                               |
| エディタ/IDE連携ツール | 開発者に対して、コーディング支援機能（補完、定義ジャンプ等）を強化したい             | リアルタイム性、軽量性が求められる           | ・コンテキスト情報を効率的に取得・更新する手段がない                                                              |

## 採用する技術スタック

| カテゴリ       | 技術・ツール      | 目的・理由                                                                 |
| :------------- | :---------------- | :------------------------------------------------------------------------- |
| プログラミング言語 | Python 3.11+    | ライブラリ開発、AST（抽象構文木）解析機能の利用                                |
| パッケージ管理   | pip, uv           | ライブラリのインストール、依存関係管理                                           |
| 設定ファイル     | YAML (.kotemari.yml) | ユーザーによる除外ルール、キャッシュ動作などのカスタマイズ                         |
| バージョン管理   | Git               | .gitignoreによる除外ルールの参照                                             |
| テスト         | pytest, pytest-cov | ライブラリの品質保証、テストカバレッジ計測                                     |
| ドキュメント     | Markdown          | README、設計文書、ユーザーガイド等の作成                                      |

## 機能（ユースケース）一覧

| 機能ID  | 機能（ユースケース）名                     | 機能の概要                                                                                                | イメージ                                                                                                                               |
| :------ | :--------------------------------------- | :-------------------------------------------------------------------------------------------------------- | :------------------------------------------------------------------------------------------------------------------------------------- |
| UC-01   | プロジェクト解析                         | 指定されたプロジェクトルートからディレクトリツリーを走査し、言語特性や除外ルールに基づいて関連ファイルを特定する。                         | `kotemari analyze <project_root>` のようなコマンドでプロジェクト内のファイル構造を把握する。                                                   |
| UC-02   | システムプロンプト生成                   | 解析結果（関連ファイルの内容）を結合・整形し、LLMなどのシステムプロンプトとして利用可能な形式で出力する。                           | `kotemari prompt <target_file>` で、指定ファイルに関連するコンテキストを整形して出力。                                                 |
| UC-03   | キャッシュ管理と変更検出                 | ファイルの更新日時やハッシュ値を記録・キャッシュし、変更があったファイルのみ再解析することで、処理を高速化する。                        | 一度解析したプロジェクトは、変更がない限りキャッシュを利用して高速にコンテキストを取得できる。                                             |
| UC-04   | 構文解析と依存関係抽出                 | コード（Pythonの場合はAST）を解析し、ファイル間の依存関係（import、呼び出し等）を特定する。他言語は拡張可能にする。                   | PythonファイルAがどのモジュールをimportし、どの関数を呼び出しているかを特定する。                                                        |
| UC-05   | 外部ライブラリドキュメント取り込み         | 設定されたURLから外部ライブラリのドキュメントを取得し、ローカルにキャッシュしてコンテキスト情報に含める。                              | プロジェクトで利用しているrequestsライブラリのドキュメントを自動取得し、関連情報として参照できるようにする。                                   |
| UC-06   | インストールとセットアップ               | pipで簡単にインストールでき、基本的な設定（もしあれば）を行えるようにする。CLIツールまたはライブラリとして利用可能。                    | `pip install kotemari` でインストール完了。すぐにCLIコマンドが使える。                                                               |
| UC-07   | ユーザー設定によるカスタマイズ           | `.kotemari.yml`のような設定ファイルで、ユーザーが除外ルール、キャッシュ設定、解析対象などを細かく調整できるようにする。                | 特定のディレクトリや拡張子を解析対象外に設定したり、キャッシュの有効期限を設定したりする。                                               |
| UC-08   | エラーハンドリング                       | 解析中のエラー（ファイルアクセス不可、構文エラー等）を適切に処理し、ユーザーに分かりやすい例外情報を提供する。                          | 解析に失敗した場合、どのファイルで何が問題だったかを示す例外 (`KotemariError` など) を送出する。                                           |
| UC-09   | ファイル一覧・ツリー表示                 | 解析対象となったファイルの一覧や、ディレクトリ構造をツリー形式で文字列として出力する機能を提供する。                                | `kotemari list` や `kotemari tree` コマンドで、プロジェクト内の認識されているファイル構造を確認できる。                                  |
| UC-10   | API提供                                  | 他のツールやスクリプトから簡単にプロジェクトコンテキストを取得・利用できるように、シンプルなPython APIを提供する。                     | 開発中のエディタ拡張機能から `kotemari.get_context()` のような関数を呼び出して、現在のファイルのコンテキスト情報を取得する。                   |

</rewritten_file> 